@@ -1,14 +1,14 @@
 #
 # This file is part of ElasticSearchX-Model
 #
-# This software is Copyright (c) 2015 by Moritz Onken.
+# This software is Copyright (c) 2016 by Moritz Onken.
 #
 # This is free software, licensed under:
 #
 #   The (three-clause) BSD License
 #
 package ElasticSearchX::Model::Document::Mapping;
-$ElasticSearchX::Model::Document::Mapping::VERSION = '0.2.2';
+$ElasticSearchX::Model::Document::Mapping::VERSION = '1.0.0';
 use strict;
 use warnings;
 use Moose::Util::TypeConstraints;
@@ -20,12 +20,19 @@ sub maptc {
     $constraint ||= find_type_constraint('Str');
     ( my $name = $constraint->name ) =~ s/\[.*\]/\[\]/;
     my $sub = $MAPPING{$name};
+    my %ret;
     if ( !$sub && $constraint->has_parent ) {
-        return maptc( $attr, $constraint->parent );
+        %ret = maptc( $attr, $constraint->parent );
     }
     elsif ($sub) {
-        return $sub->( $attr, $constraint );
+        %ret = $sub->( $attr, $constraint );
     }
+
+    if ( $ret{type} ne 'string' ) {
+        delete $ret{ignore_above};
+    }
+
+    return %ret;
 }
 
 $MAPPING{Any} = sub {
@@ -33,7 +40,6 @@ $MAPPING{Any} = sub {
     my ( $attr, $tc ) = @_;
 
     my %mapping = (
-        store => $attr->store,
         $attr->index            ? ( index          => $attr->index )   : (),
         $attr->type eq 'object' ? ( dynamic        => $attr->dynamic ) : (),
         $attr->boost            ? ( boost          => $attr->boost )   : (),
@@ -59,7 +65,6 @@ $MAPPING{Str} = sub {
                     $attr->not_analyzed
                     ? (
                         $attr->name => {
-                            store        => $attr->store,
                             index        => 'not_analyzed',
                             ignore_above => 2048,
                             doc_values   => \1,
@@ -75,20 +80,21 @@ $MAPPING{Str} = sub {
                 analyzed => {
                     store => $attr->store,
                     index => 'analyzed',
+                    type  => $attr->type,
                     $attr->boost ? ( boost => $attr->boost ) : (),
-                    type      => $attr->type,
-                    fielddata => { format => 'disabled' },
                     %term,
-                    analyzer => shift @analyzer
+                    analyzer => shift @analyzer,
+                    $attr->type eq 'string'
+                    ? ( fielddata => { format => 'disabled' } )
+                    : (),
                 },
                 (
                     map {
                         $_ => {
                             store => $attr->store,
                             index => 'analyzed',
+                            type  => $attr->type,
                             $attr->boost ? ( boost => $attr->boost ) : (),
-                            type      => $attr->type,
-                            fielddata => { format => 'disabled' },
                             %term,
                             analyzer => $_
                             }
@@ -192,9 +198,11 @@ sub _set_doc_values {
     if ( $mapping{type} eq 'string'
         && ( $mapping{index} || 'analyzed' ) eq 'analyzed' )
     {
-        $mapping{fielddata} = { format => 'disabled' };
         delete $mapping{doc_values};
     }
+    elsif ( $mapping{type} eq 'multi_field' ) {
+        delete $mapping{fielddata};
+    }
     else {
         $mapping{doc_values} = \1;
         delete $mapping{fielddata};
@@ -215,7 +223,7 @@ ElasticSearchX::Model::Document::Mapping
 
 =head1 VERSION
 
-version 0.2.2
+version 1.0.0
 
 =head1 AUTHOR
 
@@ -223,7 +231,7 @@ Moritz Onken
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2015 by Moritz Onken.
+This software is Copyright (c) 2016 by Moritz Onken.
 
 This is free software, licensed under:
 
