@@ -1,14 +1,14 @@
 #
 # This file is part of ElasticSearchX-Model
 #
-# This software is Copyright (c) 2015 by Moritz Onken.
+# This software is Copyright (c) 2016 by Moritz Onken.
 #
 # This is free software, licensed under:
 #
 #   The (three-clause) BSD License
 #
 package ElasticSearchX::Model::Document::Set;
-$ElasticSearchX::Model::Document::Set::VERSION = '0.2.2';
+$ElasticSearchX::Model::Document::Set::VERSION = '1.0.0';
 # ABSTRACT: Represents a query used for fetching a set of results
 use Moose;
 use MooseX::Attribute::Chained;
@@ -208,12 +208,28 @@ sub delete {
     $qs = $self->_build_qs($qs);
     my $query = $self->_build_query;
     delete $query->{_source};
-    return $self->es->delete_by_query(
+
+    my %idx_type = (
         index => $self->index->name,
-        type  => $self->type->short_name,
-        body  => $query,
+        type  => $self->type->short_name
+    );
+
+    my $sc = $self->es->scroll_helper(
+        search_type => 'scan',
+        body        => $self->_build_query,
+        size        => 500,
+        %idx_type,
         %$qs,
     );
+
+    my @ids;
+    while ( my @d = $sc->next(500) ) {
+        push @ids => map { $_->{_id} } @d;
+    }
+
+    my $bulk = $self->es->bulk_helper(%idx_type);
+    $bulk->delete_ids(@ids);
+    return $bulk->flush;
 }
 
 sub scroll {
@@ -239,7 +255,7 @@ ElasticSearchX::Model::Document::Set - Represents a query used for fetching a se
 
 =head1 VERSION
 
-version 0.2.2
+version 1.0.0
 
 =head1 SYNOPSIS
 
@@ -440,7 +456,7 @@ Moritz Onken
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2015 by Moritz Onken.
+This software is Copyright (c) 2016 by Moritz Onken.
 
 This is free software, licensed under:
 
