@@ -1,14 +1,14 @@
 #
 # This file is part of ElasticSearchX-Model
 #
-# This software is Copyright (c) 2015 by Moritz Onken.
+# This software is Copyright (c) 2016 by Moritz Onken.
 #
 # This is free software, licensed under:
 #
 #   The (three-clause) BSD License
 #
 package ElasticSearchX::Model::Document::Types;
-$ElasticSearchX::Model::Document::Types::VERSION = '0.2.2';
+$ElasticSearchX::Model::Document::Types::VERSION = '1.0.0';
 use List::MoreUtils ();
 use DateTime::Format::Epoch::Unix;
 use DateTime::Format::ISO8601;
@@ -49,15 +49,14 @@ subtype TimestampField,
     as Dict [
     enabled => Bool,
     path    => Optional [Str],
-    store   => Optional [Bool],
     index   => Optional [Str],
     slurpy HashRef,
     ];
 coerce TimestampField, from Int, via {
-    { enabled => 1, store => 1 };
+    { enabled => 1 };
 };
 coerce TimestampField, from Str, via {
-    { enabled => 1, path => $_, store => 1 };
+    { enabled => 1, path => $_ };
 };
 coerce TimestampField, from HashRef, via {
     { enabled => 1, %$_ };
@@ -192,7 +191,7 @@ ElasticSearchX::Model::Document::Types
 
 =head1 VERSION
 
-version 0.2.2
+version 1.0.0
 
 =head1 AUTHOR
 
@@ -200,7 +199,7 @@ Moritz Onken
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2015 by Moritz Onken.
+This software is Copyright (c) 2016 by Moritz Onken.
 
 This is free software, licensed under:
 
